﻿/*
  ML8511.cpp - Library for UV Intensity Sensor ML8511.
  Created by Andres Lopez, July 2, 2019.
  Released into the public domain.
*/

// Cantidad de lecturas del A/D para promediar
#define   NUMBER_OF_READINGS   8
// Curva de  calibración del sensor de intensidad UV
#define   IN_MIN    0.987
#define   IN_MAX    2.75
#define   OUT_MIN   0.0
#define   OUT_MAX   15.0


#include "Arduino.h"
#include "ML8511.h"

// Constructor
ML8511::ML8511(){}

// Begin
void ML8511::begin(int Pin)
{
  pinMode(A0+Pin, INPUT);      // ej. A0, pines analógicos de Arduino
  _pinUVOUT = Pin;
}

// Retorna la intensidad de radiación UV en mW/cm^2
float ML8511::readIntensity()
{
return((readVoltage(readAD()) - IN_MIN) * (OUT_MAX - OUT_MIN) / (IN_MAX - IN_MIN) + OUT_MIN);
}


//Retorna el valor del AD del sensor
float ML8511::readAD()
{
  unsigned int uvLevel = 0;
  for(int x = 0 ; x < NUMBER_OF_READINGS ; x++) uvLevel += analogRead(_pinUVOUT);
  uvLevel /= NUMBER_OF_READINGS;
  return(uvLevel);
}


//Retorna el valor de tensión del sensor (Return outputVotage)
float ML8511::readVoltage(int uvLevel)
{
  int refLevel = 665; // valor del conversor A/D cuando lee la tensión de alimentación de 3,3V del Arduino
  //Usa el pin de alimentación de 3.3V como referencia para darle más precisión al sensor UV
  float Voltage = (3.3 / refLevel) * uvLevel;
  return(Voltage);
}
