/**************************************************************************/
/*  MQ135.cpp
@author   G.Krocker (Mad Frog Labs)
@license  GNU GPLv3
First version of an Arduino Library for the MQ135 gas sensor
TODO: Review the correction factor calculation. This currently relies on
the datasheet but the information there seems to be wrong.
v1.0 - First release
*/
/**************************************************************************/

#include "MQ135.h"

// Default constructor
MQ135::MQ135() {}

// Begin (define la entrada si la calibracion del sensor)
void MQ135::begin(int pin, bool print){
    _pin = pin;
    float rzero = getRZero();  // Calibracion inicial
    if (print) {
        Serial.print("MQ135 RZERO Calibration Value : ");
        Serial.println(rzero);
    }
}

//  Get the correction factor to correct for temperature and humidity
//  return The calculated correction factor
float MQ135::getCorrectionFactor(float t, float h) {
  return CORA * t * t - CORB * t + CORC - (h-33.)*CORD;
}

// Get the resistance of the sensor, ie. the measurement value
// return The sensor resistance in kOhm
float MQ135::getResistance() {
  int val = analogRead(_pin);
  return ((1023./(float)val) * 5. - 1.)*RLOAD;
}

// Get the resistance of the sensor, ie. the measurement value corrected for temp/hum
// return The corrected sensor resistance kOhm
float MQ135::getCorrectedResistance(float t, float h) {
  return getResistance()/getCorrectionFactor(t, h);
}

// Get the ppm of CO2 sensed (assuming only CO2 in the air)
// return The ppm of CO2 in the air
float MQ135::readCO2() {
  return PARA * pow((getResistance()/RZERO), -PARB);
}

// Get the ppm of CO2 sensed (assuming only CO2 in the air), corrected for temp/hum
// return The ppm of CO2 in the air
float MQ135::getCorrectedPPM(float t, float h) {
  return PARA * pow((getCorrectedResistance(t, h)/RZERO), -PARB);
}

// Get the resistance RZero of the sensor for calibration purposes
// return The sensor resistance RZero in kOhm
float MQ135::getRZero() {
  return getResistance() * pow((ATMOCO2/PARA), (1./PARB));
}

// Get the corrected resistance RZero of the sensor for calibration purposes
// return The corrected sensor resistance RZero in kOhm
float MQ135::getCorrectedRZero(float t, float h) {
  return getCorrectedResistance(t, h) * pow((ATMOCO2/PARA), (1./PARB));
}
