#include "Arduino.h"
#include "MQ2.h"

MQ2::MQ2() {}

void MQ2::begin(int pin, bool print){
    _pin = pin;
    Ro = MQCalibration();
    if (print) {
    Serial.print("Ro: ");
    Serial.print(Ro);
    Serial.println(" kohm");
    }
}

float MQ2::readLPG() {return MQGetGasPercentage(MQRead()/Ro,GAS_LPG);}     //LPG
float MQ2::readCO(){return MQGetGasPercentage(MQRead()/Ro,GAS_CO);}       //CO
float MQ2::readSmoke(){return MQGetGasPercentage(MQRead()/Ro,GAS_SMOKE);}    //Smoke


float MQ2::MQResistanceCalculation(int raw_adc) {
   return (((float)RL_VALUE*(1023-raw_adc)/raw_adc));
}

float MQ2::MQCalibration() {
  float val=0;

  for (int i=0;i<CALIBARAION_SAMPLE_TIMES;i++) {            //take multiple samples
    val += MQResistanceCalculation(analogRead(_pin));
    delay(CALIBRATION_SAMPLE_INTERVAL);
  }
  val = val/CALIBARAION_SAMPLE_TIMES;                   //calculate the average value

  val = val/RO_CLEAN_AIR_FACTOR;                        //divided by RO_CLEAN_AIR_FACTOR yields the Ro
                                                        //according to the chart in the datasheet
  return val;
}

float MQ2::MQRead() {
  int i;
  float rs=0;
  int val = analogRead(_pin);

  for (i=0;i<READ_SAMPLE_TIMES;i++) {
    rs += MQResistanceCalculation(val);
    delay(READ_SAMPLE_INTERVAL);
  }

  rs = rs/READ_SAMPLE_TIMES;
  return rs;
}

float MQ2::MQGetGasPercentage(float rs_ro_ratio, int gas_id) {
  if ( gas_id == GAS_LPG ) {
     return MQGetPercentage(rs_ro_ratio,LPGCurve);
  } else if ( gas_id == GAS_CO ) {
     return MQGetPercentage(rs_ro_ratio,COCurve);
  } else if ( gas_id == GAS_SMOKE ) {
     return MQGetPercentage(rs_ro_ratio,SmokeCurve);
  }
  return 0;
}

int MQ2::MQGetPercentage(float rs_ro_ratio, float *pcurve) {
  return (pow(10,(((log(rs_ro_ratio)-pcurve[1])/pcurve[2]) + pcurve[0])));
}
